@@ -1,7 +1,7 @@
 
 package XML::SRS;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 BEGIN { our $PROTOCOL_VERSION = "5.0" };
 use XML::SRS::Version;
@@ -37,10 +37,15 @@ use XML::SRS::Registrar::Update;
 use XML::SRS::Domain::Create;
 use XML::SRS::Domain::Update;
 use XML::SRS::Domain::Query;
+use XML::SRS::Domain::Transferred;
 use XML::SRS::UDAIValid::Query;
 use XML::SRS::Handle::Create;
 use XML::SRS::Handle::Update;
 use XML::SRS::Handle::Query;
+use XML::SRS::Message;
+use XML::SRS::Message::Ack::Response;
+use XML::SRS::GetMessages;
+use XML::SRS::AckMessage;
 
 # ActionResponse types:
 use XML::SRS::Error;
